Section

Enum Section 

pub enum Section {
Show 43 variants NOP, Code(Code), RunAtOffset(u16, u16), SectionSwitch(u16), BSS(u32), Patch(Patch), XDEF(XDEF), XREF(XREF), LNKHeader(LNKHeader), LocalSymbol(LocalSymbol), GroupSymbol(GroupSymbol), ByteSizeRegister(u16), WordSizeRegister(u16), LongSizeRegister(u16), Filename(Filename), SetToFile(u16, u32), SetToLine(u32), IncrementLineNumber, IncrementLineNumberByte(u8), IncrementLineNumberWord(u32), VeryLocalSymbol(LocalSymbol), Set3ByteRegister(u16), SetMXInfo(SetMXInfo), CPU(u8), XBSS(XBSS), IncSLDLineNum(u16), IncSLDLineNumByte(u16, u8), IncSLDLineNumWord(u16, u32), SetSLDLineNum(SetSLDLineNum), SetSLDLineNumFile(SetSLDLineNumFile), EndSLDInfo(u16), RepeatByte(u32), RepeatWord(u32), RepeatLong(u32), ProcedureCall(ProcedureCall), ProcedureDefinition(ProcedureDefinition), Repeat3Byte(u32), FunctionStart(FunctionStart), FunctionEnd(SectionOffsetLine), BlockStart(SectionOffsetLine), BlockEnd(SectionOffsetLine), Def(Def), Def2(Def2),
}
A section within an OBJ file.

Sections can contain code, data, relocations, symbols, or debug information. The section list is terminated by a NOP entry.

Section Types

  • Code: Executable machine code
  • BSS: Uninitialized data
  • XDEF/XREF: Symbol exports and imports
  • Patch: Relocation information
  • Debug information: Line numbers, function info, etc.
  • And many more!

Variants



NOP

End of file marker.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x0


Code(Code)

Machine code.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x2
1CodeA Code structure


RunAtOffset(u16, u16)

Run at offset.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x4
1u16
3u16


SectionSwitch(u16)

Switch to different section.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x2
1u16Section ID


BSS(u32)

Uninitialized data (BSS) with size in bytes.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x8
1u32Size in bytes


Patch(Patch)

Relocation patch.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0xA
1PatchA Patch structure


XDEF(XDEF)

External symbol definition.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0xC
1XDEFAn XDEF structure.


XREF(XREF)

External symbol reference.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0xE
1XREFAn XREF structure.


LNKHeader(LNKHeader)

Section header.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x10
1LNKHeaderAn LNKHeader structure.


LocalSymbol(LocalSymbol)

Local symbol.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x12
1LocalSymbolA LocalSymbol structure


GroupSymbol(GroupSymbol)

Group symbol.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x14
1GroupSymbolA GroupSymbol structure.


ByteSizeRegister(u16)

Untested



WordSizeRegister(u16)

Untested



LongSizeRegister(u16)

Untested



Filename(Filename)

File name reference.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x1C
1FilenameA Filename structure.


SetToFile(u16, u32)

Untested



SetToLine(u32)

Untested



IncrementLineNumber

Untested



IncrementLineNumberByte(u8)

Untested



IncrementLineNumberWord(u32)

Untested



VeryLocalSymbol(LocalSymbol)

Untested



Set3ByteRegister(u16)

Untested



SetMXInfo(SetMXInfo)

Set MX info.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x2C
1SetMXInfoA SetMXInfo structure.


CPU(u8)

CPU type specification.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x2E
1u8A CPU identifier.

Constants for CPU identifiers can be found in the cputype module.



XBSS(XBSS)

External BSS symbol.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x30
1XBSSAn XBSS structure.


IncSLDLineNum(u16)

Increment line number.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x32
1u16The offset where the new line number starts.

See also: IncSLDLineNumByte, IncSLDLineNumWord



IncSLDLineNumByte(u16, u8)

Increment line number by an amount.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x34
1u16The offset where the new line number starts.
3u8The amount to increment the line number.

See also IncSLDLineNum, IncSLDLineNumWord



IncSLDLineNumWord(u16, u32)

Increment line number by an amount.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x34
1u16The offset where the new line number starts.
3u8The amount to increment the line number.

See also: IncSLDLineNum, IncSLDLineNumByte



SetSLDLineNum(SetSLDLineNum)

Set line number.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x38
1SetSLDLineNumA SetSLDLineNum structure.

See also: SetSLDLineNumFile



SetSLDLineNumFile(SetSLDLineNumFile)

Set line number with file name.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x3A
1SetSLDLineNumFileA SetSLDLineNumFile structure.

See also: SetSLDLineNum



EndSLDInfo(u16)

End of SLD info.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x3C
1u16Offset where SLD info ends.


RepeatByte(u32)

Untested



RepeatWord(u32)

Untested



RepeatLong(u32)

Untested



ProcedureCall(ProcedureCall)

Untested



ProcedureDefinition(ProcedureDefinition)

Untested



Repeat3Byte(u32)

Untested



FunctionStart(FunctionStart)

Function start marker.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x4A
1FunctionStartA FunctionStart structure.


FunctionEnd(SectionOffsetLine)

Function end marker.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x4C
1SectionOffsetLineA SectionOffsetLine structure.


BlockStart(SectionOffsetLine)

Block start marker.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x4E
1SectionOffsetLineA SectionOffsetLine structure.


BlockEnd(SectionOffsetLine)

Block end marker.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x50
1SectionOffsetLineA SectionOffsetLine structure.


Def(Def)

Variable/type definition.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x52
1DefA Def structure.


Def2(Def2)

Extended definition with tag.

Structure on Disk

OffsetTypeDescription
0u8Magic: 0x54
1Def2A Def2 structure.