pub struct Export { /* private fields */ }Expand description
An exported symbol from a module.
Exports represent functions or data that are made available to the linker for use by other modules.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Size of the symbol name. |
| 0 | [u8] | The ASCII name of of the exported symbol. Not NULL terminated. |
Implementations