LIB

Struct LIB 

pub struct LIB { /* private fields */ }
A LIB is an archive of several OBJ files. It consists of a magic number followed by one or more Modules.

A LIB file can be constructed from a u8 slice using read.

use std::path::Path;
use psyk::io;
let lib = io::read_lib(Path::new("SOME.LIB"));

Structure on Disk

OffsetTypeDescription
0[u8;3]Magic: “LIB”
3u8Archive format version (1)
4[Module]One or more Modules which wrap OBJ files.

Implementations

Source

impl LIB

pub fn new(objs: Vec<Module>) -> Self

Creates a new LIB with the provided modules.

pub fn modules(&self) -> &Vec<Module>

The modules contained in this library.

Each module wraps an OBJ file along with metadata about its name, creation time, and exported symbols.