pub struct ModuleMetadata { /* private fields */ }Expand description
Metadata for a module within a LIB archive.
This includes the module name (up to 8 characters), creation timestamp, and a list of exported symbols.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | [u8; 8] | Module name in ASCII. Padded to 8-bytes with spaces. |
| 8 | u32 | A creation timestamp for the module. The format is described in FromPSYQTimestamp. |
| 12 | u32 | An offset to the end of the module metadata. |
| 16 | u32 | The size of the serialized OBJ structure. |
| 20 | [Export] | An array of Export structs which declare any exported symbols. |
The list of Exports is terminated with a zero-length entry (a single byte with the value zero).
With the exception of the exports and offset, all other fields are derived from file system metadata. Including the exports at this level allows a linker to bypass the OBJ if it doesn’t contain any relevant symbols. The exports can be retrieved by querying the OBJ directly using OBJ::exports.
Implementations
Sourceimpl ModuleMetadata
impl ModuleMetadata
pub fn new( name: String, created: SystemTime, size: u32, exports: Vec<Export>, ) -> Self
pub fn new_from_path(path: &Path, obj: &OBJ) -> Result<Self>
Sourcepub fn name(&self) -> String
pub fn name(&self) -> String
Returns the module name, with trailing whitespace removed.
Names will be at most 8-ASCII characters long (or 8 UTF-8 bytes).
Sourcepub fn exports(&self) -> Vec<String>
pub fn exports(&self) -> Vec<String>
Returns a list of symbol names exported by this module.
Empty exports (the terminator entry) are filtered out.
Sourcepub fn created(&self) -> String
pub fn created(&self) -> String
Returns the creation timestamp as a formatted string.
Format: DD-MM-YY HH:MM:SS
Example
15-05-96 16:09:38Sourcepub fn created_datetime(&self) -> Option<NaiveDateTime>
pub fn created_datetime(&self) -> Option<NaiveDateTime>
Returns the creation timestamp as a NaiveDateTime.
Returns None if the timestamp is invalid.
Sourcepub fn created_at(&self) -> Option<SystemTime>
pub fn created_at(&self) -> Option<SystemTime>
Returns the creation timestamp as a SystemTime.
Returns None if the timestamp is invalid.
Note: The original timestamp has no timezone information, so it’s treated as UTC for conversion purposes.