Patch

Struct Patch 

pub struct Patch { /* private fields */ }
A relocation patch to be applied by the linker.

Patches modify code or data at a specific offset using a calculated expression.

Types

TagDescriptionExpression
8Write 32-bit expression value (big-endian?)``
10Unknown
16Write 32-bit expression value (little-endian?)``
30Possibly related to register allocation.
74Function symbol relocation (24-bit, little-endian).[14]
82Copy expression high 16-bytes into instruction low bytes($20+sectbase(f001))
84Copy expression low 16-bytes into instruction low bytes($20+sectbase(f001))

Structure on Disk

OffsetTypeDescription
0u8The type of patch.
1u16Offset in the section where the patch should be applied.
3ExpressionAn Expression to use calculate the patch value.