pub struct XDEF { /* private fields */ }Expand description
An external symbol definition (XDEF).
XDEF entries define symbols that are exported from this module and can be referenced by other modules.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u16 | Number. |
| 2 | u16 | Section ID. |
| 4 | u32 | Offset (TODO: relative to what?) |
| 8 | u8 | Size of the symbol name string. |
| 9 | [u8] | The symbol name. Not NULL terminated. |
Implementations