pub enum Section {
Show 43 variants
NOP,
Code(Code),
RunAtOffset(u16, u16),
SectionSwitch(u16),
BSS(u32),
Patch(Patch),
XDEF(XDEF),
XREF(XREF),
LNKHeader(LNKHeader),
LocalSymbol(LocalSymbol),
GroupSymbol(GroupSymbol),
ByteSizeRegister(u16),
WordSizeRegister(u16),
LongSizeRegister(u16),
Filename(Filename),
SetToFile(u16, u32),
SetToLine(u32),
IncrementLineNumber,
IncrementLineNumberByte(u8),
IncrementLineNumberWord(u32),
VeryLocalSymbol(LocalSymbol),
Set3ByteRegister(u16),
SetMXInfo(SetMXInfo),
CPU(u8),
XBSS(XBSS),
IncSLDLineNum(u16),
IncSLDLineNumByte(u16, u8),
IncSLDLineNumWord(u16, u32),
SetSLDLineNum(SetSLDLineNum),
SetSLDLineNumFile(SetSLDLineNumFile),
EndSLDInfo(u16),
RepeatByte(u32),
RepeatWord(u32),
RepeatLong(u32),
ProcedureCall(ProcedureCall),
ProcedureDefinition(ProcedureDefinition),
Repeat3Byte(u32),
FunctionStart(FunctionStart),
FunctionEnd(SectionOffsetLine),
BlockStart(SectionOffsetLine),
BlockEnd(SectionOffsetLine),
Def(Def),
Def2(Def2),
}Expand description
A section within an OBJ file.
Sections can contain code, data, relocations, symbols, or debug information. The section list is terminated by a NOP entry.
Section Types
Variants
NOP
Code(Code)
RunAtOffset(u16, u16)
SectionSwitch(u16)
BSS(u32)
Uninitialized data (BSS) with size in bytes.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x8 |
| 1 | u32 | Size in bytes |
Patch(Patch)
XDEF(XDEF)
External symbol definition.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0xC |
| 1 | XDEF | An XDEF structure. |
XREF(XREF)
External symbol reference.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0xE |
| 1 | XREF | An XREF structure. |
LNKHeader(LNKHeader)
Section header.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x10 |
| 1 | LNKHeader | An LNKHeader structure. |
LocalSymbol(LocalSymbol)
Local symbol.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x12 |
| 1 | LocalSymbol | A LocalSymbol structure |
GroupSymbol(GroupSymbol)
Group symbol.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x14 |
| 1 | GroupSymbol | A GroupSymbol structure. |
ByteSizeRegister(u16)
Untested
WordSizeRegister(u16)
Untested
LongSizeRegister(u16)
Untested
Filename(Filename)
File name reference.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x1C |
| 1 | Filename | A Filename structure. |
SetToFile(u16, u32)
Untested
SetToLine(u32)
Untested
IncrementLineNumber
Untested
IncrementLineNumberByte(u8)
Untested
IncrementLineNumberWord(u32)
Untested
VeryLocalSymbol(LocalSymbol)
Untested
Set3ByteRegister(u16)
Untested
SetMXInfo(SetMXInfo)
Set MX info.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x2C |
| 1 | SetMXInfo | A SetMXInfo structure. |
CPU(u8)
CPU type specification.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x2E |
| 1 | u8 | A CPU identifier. |
Constants for CPU identifiers can be found in the cputype module.
XBSS(XBSS)
IncSLDLineNum(u16)
Increment line number.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x32 |
| 1 | u16 | The offset where the new line number starts. |
See also: IncSLDLineNumByte, IncSLDLineNumWord
IncSLDLineNumByte(u16, u8)
Increment line number by an amount.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x34 |
| 1 | u16 | The offset where the new line number starts. |
| 3 | u8 | The amount to increment the line number. |
See also IncSLDLineNum, IncSLDLineNumWord
IncSLDLineNumWord(u16, u32)
Increment line number by an amount.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x34 |
| 1 | u16 | The offset where the new line number starts. |
| 3 | u8 | The amount to increment the line number. |
See also: IncSLDLineNum, IncSLDLineNumByte
SetSLDLineNum(SetSLDLineNum)
Set line number.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x38 |
| 1 | SetSLDLineNum | A SetSLDLineNum structure. |
See also: SetSLDLineNumFile
SetSLDLineNumFile(SetSLDLineNumFile)
Set line number with file name.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x3A |
| 1 | SetSLDLineNumFile | A SetSLDLineNumFile structure. |
See also: SetSLDLineNum
EndSLDInfo(u16)
End of SLD info.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x3C |
| 1 | u16 | Offset where SLD info ends. |
RepeatByte(u32)
Untested
RepeatWord(u32)
Untested
RepeatLong(u32)
Untested
ProcedureCall(ProcedureCall)
Untested
ProcedureDefinition(ProcedureDefinition)
Untested
Repeat3Byte(u32)
Untested
FunctionStart(FunctionStart)
Function start marker.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x4A |
| 1 | FunctionStart | A FunctionStart structure. |
FunctionEnd(SectionOffsetLine)
Function end marker.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x4C |
| 1 | SectionOffsetLine | A SectionOffsetLine structure. |
BlockStart(SectionOffsetLine)
Block start marker.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x4E |
| 1 | SectionOffsetLine | A SectionOffsetLine structure. |
BlockEnd(SectionOffsetLine)
Block end marker.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x50 |
| 1 | SectionOffsetLine | A SectionOffsetLine structure. |
Def(Def)
Variable/type definition.
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | Magic: 0x52 |
| 1 | Def | A Def structure. |
Def2(Def2)