pub struct Patch { /* private fields */ }Expand description
A relocation patch to be applied by the linker.
Patches modify code or data at a specific offset using a calculated expression.
Types
| Tag | Description | Expression |
|---|---|---|
| 8 | Write 32-bit expression value (big-endian?) | `` |
| 10 | Unknown | |
| 16 | Write 32-bit expression value (little-endian?) | `` |
| 30 | Possibly related to register allocation. | |
| 74 | Function symbol relocation (24-bit, little-endian). | [14] |
| 82 | Copy expression high 16-bytes into instruction low bytes | ($20+sectbase(f001)) |
| 84 | Copy expression low 16-bytes into instruction low bytes | ($20+sectbase(f001)) |
Structure on Disk
| Offset | Type | Description |
|---|---|---|
| 0 | u8 | The type of patch. |
| 1 | u16 | Offset in the section where the patch should be applied. |
| 3 | Expression | An Expression to use calculate the patch value. |